@@ -35,6 +35,7 @@
 /*==================================================================*/
 
 #include <allegro.h>
+#include <string.h>
 
 #include "config.h"
 #include "disk.h"
@@ -43,6 +44,7 @@
 #include "mouse.h"
 #include "palette.h"
 #include "startup.h"
+#include "server.h"
 
 /*==================================================================*/
 /* variables globales                                               */
@@ -86,7 +88,11 @@
 #define LABEL_PAGE_FLIP "PAGE_FLIP"
 #define LABEL_LANGAGE "LANGUAGE"
 #define LABEL_WAVE_ON "WAVE_ON"
-#define LABEL_FPS_LIMIT "FPS_LIMIT"
+#define LABEL_FRAMES_PER_SEC_LIMIT "FRAMES_PER_SEC_LIMIT"
+#define LABEL_ROUNDS_PER_SEC_LIMIT "ROUNDS_PER_SEC_LIMIT"
+#define LABEL_NICKNAME "NICKNAME"
+#define LABEL_SERVER_ADDRESS "SERVER_ADDRESS"
+#define LABEL_SERVER_PORT "SERVER_PORT"
 
 int CONFIG_GFX_GAME;
 int CONFIG_GFX_MENU;
@@ -122,12 +128,21 @@ int CONFIG_CPU_ADVANTAGE;
 int CONFIG_PAGE_FLIP;
 int CONFIG_LANGAGE;
 int CONFIG_WAVE_ON;
-int CONFIG_FPS_LIMIT;
+int CONFIG_FRAMES_PER_SEC_LIMIT;
+int CONFIG_ROUNDS_PER_SEC_LIMIT;
+char CONFIG_NICKNAME[NICKNAME_SIZE+1];
+char CONFIG_SERVER_ADDRESS[SERVER_ADDRESS_SIZE+1];
+int CONFIG_SERVER_PORT;
 
 /*==================================================================*/
-/* constantes                                                       */
+/* constantes globales                                              */
 /*==================================================================*/
 
+int DISPLAY_DELAY_MIN[9]={0, 10,15,20,25,
+			  33,50,66,100};
+int LOGIC_DELAY_MIN[9]={0, 1, 2, 5, 10,
+			15, 20, 33, 50};
+
 /*------------------------------------------------------------------*/
 /* fonctions de gestion des parametres de configuration             */
 /*------------------------------------------------------------------*/
@@ -135,8 +150,13 @@ int CONFIG_FPS_LIMIT;
 /*------------------------------------------------------------------*/
 void load_default_options (void)
 {
+#ifdef ALLEGRO_DOS
  CONFIG_GFX_GAME=0;
  CONFIG_GFX_MENU=2;
+#else
+ CONFIG_GFX_GAME=2;
+ CONFIG_GFX_MENU=2;
+#endif
  CONFIG_VIEWPORT_SIZE=5;
  
  CONFIG_WAVE_NUMBER[0]=2;
@@ -164,16 +184,16 @@ void load_default_options (void)
  CONFIG_CLICK_VOLUME=8;
  CONFIG_WATER_VOLUME_MENU=4;
  CONFIG_WATER_VOLUME_GAME=6;
- CONFIG_LEVEL_MAP=24;
- CONFIG_LEVEL_FG=121;
- CONFIG_LEVEL_BG=126;
+ CONFIG_LEVEL_MAP=0;
+ CONFIG_LEVEL_FG=135;
+ CONFIG_LEVEL_BG=131;
  CONFIG_FIGHTER_NUMBER=16;
  
  CONFIG_KEY_UP[0]= KEY_UP;
  CONFIG_KEY_DOWN[0]= KEY_DOWN;
  CONFIG_KEY_LEFT[0]= KEY_LEFT;
  CONFIG_KEY_RIGHT[0]= KEY_RIGHT;
- CONFIG_TEAM_COLOR[0]=4;
+ CONFIG_TEAM_COLOR[0]=1;
  CONFIG_CPU_CONTROL[0]=0;
  
  CONFIG_KEY_UP[1]= KEY_I;
@@ -208,7 +228,7 @@ void load_default_options (void)
  CONFIG_KEY_DOWN[5]= KEY_MOUSE_DOWN;
  CONFIG_KEY_LEFT[5]= KEY_MOUSE_LEFT;
  CONFIG_KEY_RIGHT[5]= KEY_MOUSE_RIGHT;
- CONFIG_TEAM_COLOR[5]=9;
+ CONFIG_TEAM_COLOR[5]=4;
  CONFIG_CPU_CONTROL[5]=1;
 
  CONFIG_GAME_TIME=8;
@@ -219,7 +239,13 @@ void load_default_options (void)
  CONFIG_PAGE_FLIP=0;
  CONFIG_LANGAGE=0;
  CONFIG_WAVE_ON=1;
- CONFIG_FPS_LIMIT=6;
+
+ CONFIG_FRAMES_PER_SEC_LIMIT=6;
+ CONFIG_ROUNDS_PER_SEC_LIMIT=4;
+
+ strcpy(CONFIG_NICKNAME,"x");
+ strcpy(CONFIG_SERVER_ADDRESS,LW_SERVER_DEFAULT_ADDRESS);
+ CONFIG_SERVER_PORT=LW_SERVER_DEFAULT_PORT;
 }
 
 /*------------------------------------------------------------------*/
@@ -281,8 +307,16 @@ static int load_disk_options (void)
 	CONFIG_PAGE_FLIP=get_config_int(LABEL_MAIN,LABEL_PAGE_FLIP,CONFIG_PAGE_FLIP);
 	CONFIG_LANGAGE=get_config_int(LABEL_MAIN,LABEL_LANGAGE,CONFIG_LANGAGE);
 	CONFIG_WAVE_ON=get_config_int(LABEL_MAIN,LABEL_WAVE_ON,CONFIG_WAVE_ON);
-	CONFIG_FPS_LIMIT=get_config_int(LABEL_MAIN,LABEL_FPS_LIMIT,CONFIG_FPS_LIMIT);
+	CONFIG_FRAMES_PER_SEC_LIMIT=get_config_int(LABEL_MAIN,LABEL_FRAMES_PER_SEC_LIMIT,CONFIG_FRAMES_PER_SEC_LIMIT);
+	CONFIG_ROUNDS_PER_SEC_LIMIT=get_config_int(LABEL_MAIN,LABEL_ROUNDS_PER_SEC_LIMIT,CONFIG_ROUNDS_PER_SEC_LIMIT);
 	
+	strncpy(CONFIG_NICKNAME,get_config_string(LABEL_MAIN,LABEL_NICKNAME,CONFIG_NICKNAME),sizeof(CONFIG_NICKNAME));
+	CONFIG_NICKNAME[sizeof(CONFIG_NICKNAME)-1]='\0';
+	strncpy(CONFIG_SERVER_ADDRESS,get_config_string(LABEL_MAIN,LABEL_SERVER_ADDRESS,CONFIG_SERVER_ADDRESS),sizeof(CONFIG_SERVER_ADDRESS));
+	CONFIG_SERVER_ADDRESS[sizeof(CONFIG_SERVER_ADDRESS)-1]='\0';
+
+	CONFIG_SERVER_PORT=get_config_int(LABEL_MAIN,LABEL_SERVER_PORT,CONFIG_SERVER_PORT);
+
 	return 1;
  }
  else
@@ -361,7 +395,13 @@ int save_config_options (void)
 	set_config_int(LABEL_MAIN,LABEL_PAGE_FLIP,CONFIG_PAGE_FLIP);
 	set_config_int(LABEL_MAIN,LABEL_LANGAGE,CONFIG_LANGAGE);
 	set_config_int(LABEL_MAIN,LABEL_WAVE_ON,CONFIG_WAVE_ON);
-	set_config_int(LABEL_MAIN,LABEL_FPS_LIMIT,CONFIG_FPS_LIMIT);
+
+	set_config_int(LABEL_MAIN,LABEL_FRAMES_PER_SEC_LIMIT,CONFIG_FRAMES_PER_SEC_LIMIT);
+	set_config_int(LABEL_MAIN,LABEL_ROUNDS_PER_SEC_LIMIT,CONFIG_ROUNDS_PER_SEC_LIMIT);
+
+	set_config_string(LABEL_MAIN,LABEL_NICKNAME,CONFIG_NICKNAME);
+	set_config_string(LABEL_MAIN,LABEL_SERVER_ADDRESS,CONFIG_SERVER_ADDRESS);
+	set_config_int(LABEL_MAIN,LABEL_SERVER_PORT,CONFIG_SERVER_PORT);
 	
  return 0;
 }
