@@ -83,11 +83,19 @@ extern int CONFIG_CPU_ADVANTAGE;
 extern int CONFIG_PAGE_FLIP;
 extern int CONFIG_LANGAGE;
 extern int CONFIG_WAVE_ON;
-extern int CONFIG_FPS_LIMIT;
+extern int CONFIG_FRAMES_PER_SEC_LIMIT;
+extern int CONFIG_ROUNDS_PER_SEC_LIMIT;
 extern char CONFIG_NICKNAME[NICKNAME_SIZE+1];
 extern char CONFIG_SERVER_ADDRESS[SERVER_ADDRESS_SIZE+1];
 extern int CONFIG_SERVER_PORT;
 
+/*==================================================================*/
+/* constantes globales                                              */
+/*==================================================================*/
+
+extern int DISPLAY_DELAY_MIN[9];
+extern int LOGIC_DELAY_MIN[9];
+
 /*==================================================================*/
 /* fonctions globales                                               */
 /*==================================================================*/
