@@ -37,6 +37,7 @@
 #include "dialog.h"
 #include "error.h"
 #include "help.h"
+#include "base.h"
 
 /*==================================================================*/
 /* variables globales                                               */
@@ -106,5 +107,41 @@ int error_no_network_support (void)
  return (standard_error("No network support"));
 }
 
+/*------------------------------------------------------------------*/
+int error_unable_to_connect(void)
+{
+  return (standard_error("Unable to join the server. This can happen if it's not correctly set up, or if you are behind a firewall."));
+}
+
+/*------------------------------------------------------------------*/
+int error_not_a_liquidwar_server(void)
+{
+  return (standard_error("This server does not seem to be a Liquid War server."));
+}
+
+/*------------------------------------------------------------------*/
+int error_wrong_version(void)
+{
+  return (standard_error("Wrong client/server versions. Server and client must have the same version (this client's version is \"" LW_VERSION "\"."));
+}
+
+/*------------------------------------------------------------------*/
+int error_network_problem(void)
+{
+  return (standard_error("A network error has occured. This often happens when the connection with the server is too slow or simply lost."));
+}
+
+/*------------------------------------------------------------------*/
+int error_cant_send_map(void)
+{
+  return (standard_error("Unable to send the map to the server."));
+}
+
+/*------------------------------------------------------------------*/
+int error_cant_receive_map(void)
+{
+  return (standard_error("Unable to receive the map from the server."));
+}
+
 
 
