@@ -49,5 +49,11 @@ int error_not_enough_teams(void);
 int error_not_enough_big_data(void);
 int error_graphics_init_failed(void);
 int error_no_network_support(void);
+int error_unable_to_connect(void);
+int error_not_a_liquidwar_server(void);
+int error_wrong_version(void);
+int error_network_problem(void);
+int error_cant_send_map(void);
+int error_cant_receive_map(void);
 
 #endif
