@@ -70,9 +70,6 @@
 /* definitions de constantes                                        */
 /*==================================================================*/
 
-static int DISPLAY_DELAY_MIN[9]={0, 10,15,20,25,
-                                    33,50,66,100};
-
 /*==================================================================*/
 /* definitions de types                                             */
 /*==================================================================*/
@@ -91,37 +88,37 @@ static int DISPLAY_DELAY_MIN[9]={0, 10,15,20,25,
  */
 void calc_playing_teams(void)
 {
- int i;
+  int i;
 
- PLAYING_TEAMS=0;
+  PLAYING_TEAMS=0;
 
- /*
-  * loop for all the possible teams, that's to say each of the
-  * 6 areas in the "teams" menu
-  */
- for (i=0;i<NB_TEAMS;++i)
-   {
-     /*
-      * check if a color has been selected, a value of 0 indicates
-      * that no color has been selected, therefore the team is
-      * disactivated
-      */
-   if (LW_NETWORK_ON)
-     {
-       if (LW_NETWORK_INFO[i].active)
-	 {
-	   PLAYING_TEAMS++;
-	 }
-     }
-     else
-     { 
-     if (CONFIG_TEAM_COLOR[i])
-        /*
-         * OK, there's a chosen color, increment the result
-         */
-        PLAYING_TEAMS++;
-     }
-   }
+  /*
+   * loop for all the possible teams, that's to say each of the
+   * 6 areas in the "teams" menu
+   */
+  for (i=0;i<NB_TEAMS;++i)
+    {
+      /*
+       * check if a color has been selected, a value of 0 indicates
+       * that no color has been selected, therefore the team is
+       * disactivated
+       */
+      if (LW_NETWORK_ON)
+	{
+	  if (LW_NETWORK_INFO[i].active)
+	    {
+	      PLAYING_TEAMS++;
+	    }
+	}
+      else
+	{ 
+	  if (CONFIG_TEAM_COLOR[i])
+	    /*
+	     * OK, there's a chosen color, increment the result
+	     */
+	    PLAYING_TEAMS++;
+	}
+    }
 }
 
 /*------------------------------------------------------------------*/
@@ -138,14 +135,14 @@ void calc_playing_teams(void)
  */
 static void init_cursor_control_method (void)
 {
- int i;
+  int i;
 
- /*
-  * loop for all the possible teams, that's to say each of the
-  * 6 areas in the "teams" menu
-  */
- for (i=0;i<NB_TEAMS;++i)
-     {
+  /*
+   * loop for all the possible teams, that's to say each of the
+   * 6 areas in the "teams" menu
+   */
+  for (i=0;i<NB_TEAMS;++i)
+    {
       /*
        * since network is not implemented, we consider that the
        * cursor is not controled by the network
@@ -156,7 +153,7 @@ static void init_cursor_control_method (void)
        * by a computer or a human.
        */
       CURRENT_CURSOR[i].cpu_or_human=CONFIG_CPU_CONTROL[i];
-     }
+    }
 }
 
 /*------------------------------------------------------------------*/
@@ -170,47 +167,47 @@ static void init_cursor_control_method (void)
  */
 int check_loose_team (void)
 {
- int i=0,lost=0;
+  int i=0,lost=0;
 
- /*
-  * loop for all the playing teams. we stop when we first find a
-  * team which has lost. however, if another one has lost, it will
-  * be discovered at the next game round, so it's not a problem
-  * and anyway, teams rarely loose at the same round 8-)
-  */
- while (i<PLAYING_TEAMS && !lost)
-       {
-        /*
-         * if there are no fighters left, then the game is lost
-         */
-        if (ACTIVE_FIGHTERS[i]==0)
-           {
-            /*
-             * nothing will be calculated for this team anymore
-             */
-            eliminate_team(i);
-            lost=1;
-           }
-        else
-            ++i;
-       }
- /*
-  * now we check if the previous loop has given some results
-  */
- if (lost)
+  /*
+   * loop for all the playing teams. we stop when we first find a
+   * team which has lost. however, if another one has lost, it will
+   * be discovered at the next game round, so it's not a problem
+   * and anyway, teams rarely loose at the same round 8-)
+   */
+  while (i<PLAYING_TEAMS && !lost)
     {
-     /*
-      * sound effect
-      */
-     play_loose();
-     /*
-      * remove the team from the info bar, so that room if freed for 
-      * other teams
-      */
-     free_info_bar();
+      /*
+       * if there are no fighters left, then the game is lost
+       */
+      if (ACTIVE_FIGHTERS[i]==0)
+	{
+	  /*
+	   * nothing will be calculated for this team anymore
+	   */
+	  eliminate_team(i);
+	  lost=1;
+	}
+      else
+	++i;
+    }
+  /*
+   * now we check if the previous loop has given some results
+   */
+  if (lost)
+    {
+      /*
+       * sound effect
+       */
+      play_loose();
+      /*
+       * remove the team from the info bar, so that room if freed for 
+       * other teams
+       */
+      free_info_bar();
     }
 
- return (lost);
+  return (lost);
 }
 
 /*------------------------------------------------------------------*/
@@ -241,8 +238,8 @@ char  *init_game (void)
       (CURRENT_AREA_BACK=create_textured_map (CONFIG_LEVEL_MAP,
                                               CONFIG_LEVEL_FG,
                                               CONFIG_LEVEL_BG))
-     ==NULL)
-     message="AB mem fail";
+      ==NULL)
+    message="AB mem fail";
 
   /*
    * creation of the map which will be used for display
@@ -253,45 +250,45 @@ char  *init_game (void)
       (CURRENT_AREA_DISP=create_textured_map (CONFIG_LEVEL_MAP,
                                               CONFIG_LEVEL_FG,
                                               CONFIG_LEVEL_BG))
-     ==NULL)
-     message="AD mem fail";
+      ==NULL)
+    message="AD mem fail";
 
   /*
    * creation of the mesh, see mesh.c for details
    */
   if (!message && create_mesh())
-     message="Mesh nem fail";
+    message="Mesh nem fail";
 
   /*
    * creation of the game area, see area.c for details
    */
   if (!message && create_game_area())
-     message="Area nem fail";
+    message="Area nem fail";
 
   /*
    * creation of the armies, see army.c for details
    */
   if (!message && create_army())
-     message="Army nem fail";
+    message="Army nem fail";
 
   /*
    * what to do nothing failed (play!)
    */
   if (!message)
-     {
-     /*
-      * these are basically initialization which need to be done 
-      * and should never fail
-      * check each function to know what it does!!!
-      */
-     reset_mesh();
-     reset_game_area();
-     reset_all_cursor();
-     init_cursor_control_method ();
-     place_all_team();
-     init_move_fighters();
-     init_disp_cursor ();
-     }
+    {
+      /*
+       * these are basically initialization which need to be done 
+       * and should never fail
+       * check each function to know what it does!!!
+       */
+      reset_mesh();
+      reset_game_area();
+      reset_all_cursor();
+      init_cursor_control_method ();
+      place_all_team();
+      init_move_fighters();
+      init_disp_cursor ();
+    }
 
   /*
    * We set the network error flag to 0, if it becomes non-zero
@@ -310,33 +307,33 @@ char  *init_game (void)
  */
 void free_game_memory (void)
 {
-     /*
-      * the info bar allocates bitmaps for its display, get rid of'm
-      */
-     free_info_bar ();
-     /*
-      * the bigdata is not "freed" in the malloc sense, but it's
-      * just clean to tell it to reset itself.it might be usefull
-      * if some day the big data system is implemented in a more
-      * conventional way
-      */
-     reset_big_data ();
-     /*
-      * free the bitmap used for displays if it exists
-      */
-     if (CURRENT_AREA_DISP)
-         {
-          destroy_bitmap (CURRENT_AREA_DISP);
-          CURRENT_AREA_DISP=0;
-         }
-     /*
-      * free the clean empty bitmap if it exists
-      */
-     if (CURRENT_AREA_BACK)
-         {
-          destroy_bitmap (CURRENT_AREA_BACK);
-          CURRENT_AREA_BACK=0;
-         }
+  /*
+   * the info bar allocates bitmaps for its display, get rid of'm
+   */
+  free_info_bar ();
+  /*
+   * the bigdata is not "freed" in the malloc sense, but it's
+   * just clean to tell it to reset itself.it might be usefull
+   * if some day the big data system is implemented in a more
+   * conventional way
+   */
+  reset_big_data ();
+  /*
+   * free the bitmap used for displays if it exists
+   */
+  if (CURRENT_AREA_DISP)
+    {
+      destroy_bitmap (CURRENT_AREA_DISP);
+      CURRENT_AREA_DISP=0;
+    }
+  /*
+   * free the clean empty bitmap if it exists
+   */
+  if (CURRENT_AREA_BACK)
+    {
+      destroy_bitmap (CURRENT_AREA_BACK);
+      CURRENT_AREA_BACK=0;
+    }
 }
 
 /*------------------------------------------------------------------*/
@@ -349,43 +346,43 @@ void free_game_memory (void)
  */
 int blank_round(void)
 {
- /*
-  * the first call to page flip allocates a bitmap for drawing,
-  * so it might fail...
-  */
- if (page_flip())
+  /*
+   * the first call to page flip allocates a bitmap for drawing,
+   * so it might fail...
+   */
+  if (page_flip())
     {
-     /*
-      * the distorsion displayer is used for the wave effect
-      */
-     init_distorsion_displayer();
-     /*
+      /*
+       * the distorsion displayer is used for the wave effect
+       */
+      init_distorsion_displayer();
+      /*
       * prepares the basic layer for the first buffer
       */
-     display_back_image();
-     rect_for_viewport ();
-     /*
-      * displays the map in the previously defined layer
-      */
-     disp_all_cursors();
-     display_area();
-     undisp_all_cursors();
-     /*
+      display_back_image();
+      rect_for_viewport ();
+      /*
+       * displays the map in the previously defined layer
+       */
+      disp_all_cursors();
+      display_area();
+      undisp_all_cursors();
+      /*
       * we now show what we have done to the player
       */
-     page_flip();
-     /*
+      page_flip();
+      /*
       * prepares the basic layer for the second buffer
       */
-     display_back_image();
-     rect_for_viewport ();
-     /*
-      * clean up message queue
-      */ 
-     clear_message();
-     return 0;
+      display_back_image();
+      rect_for_viewport ();
+      /*
+       * clean up message queue
+       */ 
+      clear_message();
+      return 0;
     }
- else
+  else
     return -1;
 }
 
@@ -402,7 +399,7 @@ static void fill_next_screen (void)
    * normally no gradient is displayed, so the gradient is 0
    */
   if (GRAD_TO_DISP==0)
-     {
+    {
       /*
        * we add the cursors to the map, temporary
        */
@@ -416,7 +413,7 @@ static void fill_next_screen (void)
        * so they are no longer required
        */
       undisp_all_cursors();
-     }
+    }
 
   /*
    * GRAD_TO_DISP is between 1 & 6, we display the info concerning
@@ -424,14 +421,14 @@ static void fill_next_screen (void)
    * the gradient is calculated. for curious guys
    */
   if (GRAD_TO_DISP>=1 && GRAD_TO_DISP<=6)
-      display_gradient(GRAD_TO_DISP-1);
+    display_gradient(GRAD_TO_DISP-1);
 
   /*
    * is GRAD_TO_DISP is 7 or 8 we display the plain mesh with
    * various display options
    */
   if (GRAD_TO_DISP>=7 && GRAD_TO_DISP<=8)
-     display_mesh(GRAD_TO_DISP-7);
+    display_mesh(GRAD_TO_DISP-7);
 }
 
 /*------------------------------------------------------------------*/
@@ -445,57 +442,57 @@ static void fill_next_screen (void)
  */
 static void logic(void)
 {
+  /*
+   * if the game is paused, we do not do everything
+   * this test is done again later
+   */
+  if (!PAUSE_ON)
+    {
       /*
-       * if the game is paused, we do not do everything
-       * this test is done again later
+       * moves the cursors. this will ask the keyboard module
+       * for information, ask the AI functions what to do...
        */
-      if (!PAUSE_ON)
-         {
-          /*
-           * moves the cursors. this will ask the keyboard module
-           * for information, ask the AI functions what to do...
-           */
-          move_all_cursors();
-          /*
-           * applying the cursors means that we communicate to
-           * the game area the information about where the cursors are
-           */
-          apply_all_cursor();
-         }
+      move_all_cursors();
       /*
-       * the profile module enables CPU time tracking, so that the player
-       * can now how much time is spent on various tasks
+       * applying the cursors means that we communicate to
+       * the game area the information about where the cursors are
        */
-      start_profile (SPREAD_PROFILE);
-      if (!PAUSE_ON)
-         /*
-          * spreads the gradient, ie calculates in the game area how far
-          * each point is from the cursors, this information depends
-          * on where the cursors are, this information being given
-          * by apply_all_cursor
-          */
-         spread_single_gradient();
-      /*
-       * this call ends the time tracking associated to the spread function
-       */
-      stop_profile (SPREAD_PROFILE);
+      apply_all_cursor();
+    }
+  /*
+   * the profile module enables CPU time tracking, so that the player
+   * can now how much time is spent on various tasks
+   */
+  start_profile (SPREAD_PROFILE);
+  if (!PAUSE_ON)
+    /*
+     * spreads the gradient, ie calculates in the game area how far
+     * each point is from the cursors, this information depends
+     * on where the cursors are, this information being given
+     * by apply_all_cursor
+     */
+    spread_single_gradient();
+  /*
+   * this call ends the time tracking associated to the spread function
+   */
+  stop_profile (SPREAD_PROFILE);
 
-      start_profile (MOVE_PROFILE);
-      if (!PAUSE_ON)
-         /*
-          * now we move the fighters, ie each fighter of each team
-          * will either move, attack his neighbor, die...
-          */
-         move_fighters();
-      stop_profile (MOVE_PROFILE);
+  start_profile (MOVE_PROFILE);
+  if (!PAUSE_ON)
+    /*
+     * now we move the fighters, ie each fighter of each team
+     * will either move, attack his neighbor, die...
+     */
+    move_fighters();
+  stop_profile (MOVE_PROFILE);
 
-      /*
-       * increments the clock, this way one can know how many game ticks
-       * there has been. there's actually no link between this clock
-       * and the GMT, indeed everything depends on the speed of the
-       * computer where the game is run
-       */
-      GLOBAL_CLOCK++;
+  /*
+   * increments the clock, this way one can know how many game ticks
+   * there has been. there's actually no link between this clock
+   * and the GMT, indeed everything depends on the speed of the
+   * computer where the game is run
+   */
+  GLOBAL_CLOCK++;
 }
 
 /*------------------------------------------------------------------*/
@@ -510,64 +507,64 @@ static void logic(void)
  */
 static void display(void)
 {
-      /*
-       * the watchdog waits for secret codes to be entered
-       */
-      watchdog_update();
+  /*
+   * the watchdog waits for secret codes to be entered
+   */
+  watchdog_update();
 
-      /*
-       * calls the watchdog module to see if a secret code has been
-       * entered, and does the required stuff if the answer is yes
-       */
-      check_code();
-      /*
-       * like check_code but dedicated to the info mode on/off
-       * ie it detects if F1 has been pressed and decides wether
-       * the info bar must be displayed or not
-       */
-      check_info_state();
+  /*
+   * calls the watchdog module to see if a secret code has been
+   * entered, and does the required stuff if the answer is yes
+   */
+  check_code();
+  /*
+   * like check_code but dedicated to the info mode on/off
+   * ie it detects if F1 has been pressed and decides wether
+   * the info bar must be displayed or not
+   */
+  check_info_state();
 
-      /*
-       * keeps track of how long the mext operation takes
-       */
-      start_profile (DISP_PROFILE);
-      /*
-       * now we call the function that actually draws stuff
-       */
-      fill_next_screen();
-      stop_profile (DISP_PROFILE);
+  /*
+   * keeps track of how long the mext operation takes
+   */
+  start_profile (DISP_PROFILE);
+  /*
+   * now we call the function that actually draws stuff
+   */
+  fill_next_screen();
+  stop_profile (DISP_PROFILE);
 
-      /*
-       * we display the system messages if needed
-       */
-      display_message();
+  /*
+   * we display the system messages if needed
+   */
+  display_message();
 
-      /*
-       * we check if a team has lost
-       */
-      check_loose_team();
+  /*
+   * we check if a team has lost
+   */
+  check_loose_team();
 
-      /*
-       * updates some time values, telling how many weeks this tremendous
-       * liquid war session has been running 8-) 
-       */
-      update_play_time();
+  /*
+   * updates some time values, telling how many weeks this tremendous
+   * liquid war session has been running 8-) 
+   */
+  update_play_time();
 
-      /*
-       * displays the info bar with the elapsed time etc... if required
-       */
-      display_info ();
+  /*
+   * displays the info bar with the elapsed time etc... if required
+   */
+  display_info ();
 
-      /*
-       * it's interesting to know how much time is wasted on page flips
-       */
-      start_profile (FLIP_PROFILE);
-      /*
-       * switches to the next screen, when page flipping is off,
-       * it does not do much...
-       */
-      page_flip ();
-      stop_profile (FLIP_PROFILE);
+  /*
+   * it's interesting to know how much time is wasted on page flips
+   */
+  start_profile (FLIP_PROFILE);
+  /*
+   * switches to the next screen, when page flipping is off,
+   * it does not do much...
+   */
+  page_flip ();
+  stop_profile (FLIP_PROFILE);
 }
 
 /*------------------------------------------------------------------*/
@@ -576,110 +573,125 @@ static void display(void)
  */
 int game (void)
 {
- int retour=0;
- int last_display_time=get_ticker();
- int lr;
+  int retour=0;
+  int last_display_time=get_ticker();
+  int last_logic_time=get_ticker();
+  int lr;
 
- /*
-  * we initialize the time module telling him that now it's 0
-  * and he it can start recording stuff
-  */
- start_play_time();
- /*
-  * resets the secret code sequences
-  */
- watchdog_reset();
- reset_code();
- /*
-  * resets input buffers and control interfaces
-  */
- reset_mouse_control();
- reset_computer_path ();
- /*
-  * resets profile information, so that they are not affected
-  * by previous games
-  */
- reset_all_profile();
+  /*
+   * we initialize the time module telling him that now it's 0
+   * and he it can start recording stuff
+   */
+  start_play_time();
+  /*
+   * resets the secret code sequences
+   */
+  watchdog_reset();
+  reset_code();
+  /*
+   * resets input buffers and control interfaces
+   */
+  reset_mouse_control();
+  reset_computer_path ();
+  /*
+   * resets profile information, so that they are not affected
+   * by previous games
+   */
+  reset_all_profile();
 
- /*
-  * everything's ready, POOOOOOOOOT the game starts and you hear it
-  */
- play_go();
+  /*
+   * everything's ready, POOOOOOOOOT the game starts and you hear it
+   */
+  play_go();
 
- if (1/*!init_distorsion_displayer()*/)
- {
- /*
-  * so we loop (almost) for ever
-  * execptions are
-  * - we have detected a key press on ESCAPE
-  * - there are less than 2 teams playing, ie there's a winner
-  * - the game time is elapsed
-  */
- while (  (!WATCHDOG_SCANCODE[KEY_ESC])
-       && (PLAYING_TEAMS>=2)
-       && (TIME_LEFT>0)
-       && (!LW_NETWORK_ERROR_DETECTED))
-     {
+  if (1/*!init_distorsion_displayer()*/)
+    {
       /*
-       * global time checking
+       * so we loop (almost) for ever
+       * execptions are
+       * - we have detected a key press on ESCAPE
+       * - there are less than 2 teams playing, ie there's a winner
+       * - the game time is elapsed
        */
-      start_profile (GLOBAL_PROFILE);
+      while (  (!WATCHDOG_SCANCODE[KEY_ESC])
+	       && (PLAYING_TEAMS>=2)
+	       && (TIME_LEFT>0)
+	       && (!LW_NETWORK_ERROR_DETECTED))
+	{
+	  /*
+	   * global time checking
+	   */
+	  start_profile (GLOBAL_PROFILE);
 
-      /*
-       * will contain how mush called to logic have been performed
-       */
-      lr=0;
-      do
-        {
-         /*
-          * we call logic, calculates stuff, move players etc...
-          */
-         logic();
-         lr++;
-        }
-      while
-           /*
-            * if CONFIG_FPS_LIMIT is 0 we stop right away, ie
-            * there will be one logic() operation for each display()
-            * if it is 1, we keep going until we exceed the
-            * CONFIG_FPS_LIMIT value. this way we avoid drawing 
-            * 300 frames / second, which is useless
-            * this method speeds the game on powerfull machines
-            * for one can limit the display to 20 frames / seconds
-            * and keep the rest of the CPU for calls to logic()
-            */
-           (CONFIG_FPS_LIMIT
-           && (get_ticker() <last_display_time
-                            +DISPLAY_DELAY_MIN
-                            [CONFIG_FPS_LIMIT]));
-      /*
-       * tells the profile module about how much logic operations
-       * have been done for this display
-       */
-      update_logic_rate(lr);
+	  /*
+	   * will contain how mush called to logic have been performed
+	   */
+	  lr=0;
+	  do
+	    {
+	      /*
+	       * we call logic, calculates stuff, move players etc...
+	       */
+	      logic();
 
-      /*
-       * we get the information "when has the last call to display() 
-       * been done"
-       */
-      last_display_time=get_ticker();
-      /*
-       * now we really display stuff, (takes time...)
-       */
-      display();
+	      /*
+	       * Now we decide to go idel if it happens that the computer
+	       * is calculating this "too fast". This will enable people
+	       * too play Liquid War even on a very very fast machine
+	       */
+	      while (get_ticker() < last_logic_time
+		     +LOGIC_DELAY_MIN
+		     [CONFIG_ROUNDS_PER_SEC_LIMIT])
+		{
+		  rest(1);
+		}	      
+	      last_logic_time=get_ticker();
 
-      stop_profile (GLOBAL_PROFILE);
-     }
- }
- /*
-  * cleans up the double buffer system
-  */
- last_flip();
+	      lr++;
+	    }
+	  while
+	    /*
+	     * if CONFIG_FPS_LIMIT is 0 we stop right away, ie
+	     * there will be one logic() operation for each display()
+	     * if it is 1, we keep going until we exceed the
+	     * CONFIG_FPS_LIMIT value. this way we avoid drawing 
+	     * 300 frames / second, which is useless
+	     * this method speeds the game on powerfull machines
+	     * for one can limit the display to 20 frames / seconds
+	     * and keep the rest of the CPU for calls to logic()
+	     */
+	    (CONFIG_FRAMES_PER_SEC_LIMIT
+	     && (get_ticker() <last_display_time
+		 +DISPLAY_DELAY_MIN
+		 [CONFIG_FRAMES_PER_SEC_LIMIT]));
+	  /*
+	   * tells the profile module about how much logic operations
+	   * have been done for this display
+	   */
+	  update_logic_rate(lr);
 
- /*
-  * empties the key buffer
-  */
- clear_keybuf ();
+	  /*
+	   * we get the information "when has the last call to display() 
+	   * been done"
+	   */
+	  last_display_time=get_ticker();
+	  /*
+	   * now we really display stuff, (takes time...)
+	   */
+	  display();
 
- return retour;
+	  stop_profile (GLOBAL_PROFILE);
+	}
+    }
+  /*
+   * cleans up the double buffer system
+   */
+  last_flip();
+
+  /*
+   * empties the key buffer
+   */
+  clear_keybuf ();
+
+  return retour;
 }
