@@ -41,6 +41,9 @@
 /* variables globales                                               */
 /*==================================================================*/
 
+extern int GFX_MODE_W[5];
+extern int GFX_MODE_H[5];
+
 /*==================================================================*/
 /* fonctions globales                                               */
 /*==================================================================*/
